==> regina-normal_6.0.orig.tar.gz: regina-6.0/qtui/src/edittableview.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Qt User Interface                                                     *
 *                                                                        *
 *  Copyright (c) 1999-2021, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/*! \file edittableview.h
 *  \brief A subclass of QTableView with enhancements for use in packet editors.
 */

#ifndef __EDITTABLEVIEW_H
#define __EDITTABLEVIEW_H

#include <QTableView>

/**
 * A subclass of QTableView for use inside a packet editor.
 */
class EditTableView : public QTableView {
    public:
        EditTableView(QWidget* parent = 0);

        /**
         * Finish any cell editing operation that might be in progress.
         */
        void endEdit();
};

inline EditTableView::EditTableView(QWidget* parent) :
        QTableView(parent) {
}

inline void EditTableView::endEdit() {
    QModelIndex index = currentIndex();
    currentChanged(index, index);
}

#endif

==> regina-normal_7.1.orig.tar.gz: regina-7.1/qtui/src/edittableview.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Qt User Interface                                                     *
 *                                                                        *
 *  Copyright (c) 1999-2022, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/*! \file edittableview.h
 *  \brief A subclass of QTableView with enhancements for use in packet editors.
 */

#ifndef __EDITTABLEVIEW_H
#define __EDITTABLEVIEW_H

#include "reginaqt.h"
#include <QTableView>

/**
 * A subclass of QTableView for use inside a packet editor.
 */
class EditTableView : public QTableView {
    public:
        EditTableView(QWidget* parent = nullptr);

        /**
         * Finish any cell editing operation that might be in progress.
         */
        void endEdit();
};

inline EditTableView::EditTableView(QWidget* parent) :
        QTableView(parent) {
}

inline void EditTableView::endEdit() {
    QModelIndex index = currentIndex();
    currentChanged(index, index);
}

#endif
